summaryrefslogtreecommitdiff
path: root/storage
diff options
context:
space:
mode:
authorMarko Mäkelä <marko.makela@mariadb.com>2018-09-19 09:12:58 +0300
committerMarko Mäkelä <marko.makela@mariadb.com>2018-09-19 09:12:58 +0300
commit28ae79650d3057ffcd849d2ef28dcd80282c85d2 (patch)
treea6b1875c3ff24e1d9bda0bcc9852aee4d00ded99 /storage
parent755187c8531ddcf3639b130bc1cd0dc36c7938f1 (diff)
downloadmariadb-git-28ae79650d3057ffcd849d2ef28dcd80282c85d2.tar.gz
Terminology: 'metadata' not 'default rec'
This follows up to commit 755187c8531ddcf3639b130bc1cd0dc36c7938f1. TRX_UNDO_INSERT_METADATA: Renamed from TRX_UNDO_INSERT_DEFAULT trx_undo_metadata: Renamed from trx_undo_default_rec
Diffstat (limited to 'storage')
-rw-r--r--storage/innobase/include/row0mysql.h2
-rw-r--r--storage/innobase/include/trx0rec.h6
-rw-r--r--storage/innobase/row/row0purge.cc10
-rw-r--r--storage/innobase/row/row0uins.cc8
-rw-r--r--storage/innobase/row/row0undo.cc2
-rw-r--r--storage/innobase/trx/trx0rec.cc6
-rw-r--r--storage/innobase/trx/trx0roll.cc2
7 files changed, 18 insertions, 18 deletions
diff --git a/storage/innobase/include/row0mysql.h b/storage/innobase/include/row0mysql.h
index c38f94f5e73..96454995e74 100644
--- a/storage/innobase/include/row0mysql.h
+++ b/storage/innobase/include/row0mysql.h
@@ -688,7 +688,7 @@ struct row_prebuilt_t {
to the Innobase format from the MySQL
format */
const byte* default_rec; /*!< the default values of all columns
- (a "metadata") in MySQL format */
+ (a "default row") in MySQL format */
ulint hint_need_to_fetch_extra_cols;
/*!< normally this is set to 0; if this
is set to ROW_RETRIEVE_PRIMARY_KEY,
diff --git a/storage/innobase/row/row0purge.cc b/storage/innobase/row/row0purge.cc
index dc575c09ad9..b02343fd952 100644
--- a/storage/innobase/row/row0purge.cc
+++ b/storage/innobase/row/row0purge.cc
@@ -1043,7 +1043,7 @@ row_purge_parse_undo_rec(
switch (type) {
case TRX_UNDO_RENAME_TABLE:
return false;
- case TRX_UNDO_INSERT_DEFAULT:
+ case TRX_UNDO_INSERT_METADATA:
case TRX_UNDO_INSERT_REC:
break;
default:
@@ -1080,7 +1080,7 @@ try_again:
}
switch (type) {
- case TRX_UNDO_INSERT_DEFAULT:
+ case TRX_UNDO_INSERT_METADATA:
case TRX_UNDO_INSERT_REC:
break;
default:
@@ -1118,8 +1118,8 @@ err_exit:
return(false);
}
- if (type == TRX_UNDO_INSERT_DEFAULT) {
- node->ref = &trx_undo_default_rec;
+ if (type == TRX_UNDO_INSERT_METADATA) {
+ node->ref = &trx_undo_metadata;
return(true);
}
@@ -1186,7 +1186,7 @@ row_purge_record_func(
MONITOR_INC(MONITOR_N_DEL_ROW_PURGE);
}
break;
- case TRX_UNDO_INSERT_DEFAULT:
+ case TRX_UNDO_INSERT_METADATA:
case TRX_UNDO_INSERT_REC:
node->roll_ptr |= 1ULL << ROLL_PTR_INSERT_FLAG_POS;
/* fall through */
diff --git a/storage/innobase/row/row0uins.cc b/storage/innobase/row/row0uins.cc
index a5d7294c9ed..d610e45edbc 100644
--- a/storage/innobase/row/row0uins.cc
+++ b/storage/innobase/row/row0uins.cc
@@ -227,7 +227,7 @@ retry:
func_exit:
btr_pcur_commit_specify_mtr(&node->pcur, &mtr);
- if (err == DB_SUCCESS && node->rec_type == TRX_UNDO_INSERT_DEFAULT) {
+ if (err == DB_SUCCESS && node->rec_type == TRX_UNDO_INSERT_METADATA) {
/* When rolling back the very first instant ADD COLUMN
operation, reset the root page to the basic state. */
ut_ad(!index->table->is_temporary());
@@ -422,7 +422,7 @@ row_undo_ins_parse_undo_rec(
default:
ut_ad(!"wrong undo record type");
goto close_table;
- case TRX_UNDO_INSERT_DEFAULT:
+ case TRX_UNDO_INSERT_METADATA:
case TRX_UNDO_INSERT_REC:
break;
case TRX_UNDO_RENAME_TABLE:
@@ -464,7 +464,7 @@ close_table:
ptr, clust_index, &node->ref,
node->heap);
} else {
- node->ref = &trx_undo_default_rec;
+ node->ref = &trx_undo_metadata;
}
if (!row_undo_search_clust_to_pcur(node)) {
@@ -596,7 +596,7 @@ row_undo_ins(
}
/* fall through */
- case TRX_UNDO_INSERT_DEFAULT:
+ case TRX_UNDO_INSERT_METADATA:
log_free_check();
if (node->table->id == DICT_INDEXES_ID) {
diff --git a/storage/innobase/row/row0undo.cc b/storage/innobase/row/row0undo.cc
index a85b817d5cb..2c261c5b9d3 100644
--- a/storage/innobase/row/row0undo.cc
+++ b/storage/innobase/row/row0undo.cc
@@ -236,7 +236,7 @@ row_undo_search_clust_to_pcur(
clust_index, node->update, node->heap);
} else {
ut_ad((node->row->info_bits == REC_INFO_MIN_REC_FLAG)
- == (node->rec_type == TRX_UNDO_INSERT_DEFAULT));
+ == (node->rec_type == TRX_UNDO_INSERT_METADATA));
node->undo_row = NULL;
node->undo_ext = NULL;
}
diff --git a/storage/innobase/trx/trx0roll.cc b/storage/innobase/trx/trx0roll.cc
index c0864e40622..f7f6dff4380 100644
--- a/storage/innobase/trx/trx0roll.cc
+++ b/storage/innobase/trx/trx0roll.cc
@@ -1019,7 +1019,7 @@ trx_roll_pop_top_rec_of_trx(trx_t* trx, roll_ptr_t* roll_ptr, mem_heap_t* heap)
trx_undo_rec_t* undo_rec = trx_roll_pop_top_rec(trx, undo, &mtr);
const undo_no_t undo_no = trx_undo_rec_get_undo_no(undo_rec);
switch (trx_undo_rec_get_type(undo_rec)) {
- case TRX_UNDO_INSERT_DEFAULT:
+ case TRX_UNDO_INSERT_METADATA:
/* This record type was introduced in MDEV-11369
instant ADD COLUMN, which was implemented after
MDEV-12288 removed the insert_undo log. There is no
diff --git a/storage/innobase/include/trx0rec.h b/storage/innobase/include/trx0rec.h
index 88c98625462..563d31e1a25 100644
--- a/storage/innobase/include/trx0rec.h
+++ b/storage/innobase/include/trx0rec.h
@@ -311,7 +311,7 @@ compilation info multiplied by 16 is ORed to this value in an undo log
record */
#define TRX_UNDO_RENAME_TABLE 9 /*!< RENAME TABLE */
-#define TRX_UNDO_INSERT_DEFAULT 10 /*!< insert a "default value"
+#define TRX_UNDO_INSERT_METADATA 10 /*!< insert a metadata
pseudo-record for instant ALTER */
#define TRX_UNDO_INSERT_REC 11 /* fresh insert into clustered index */
#define TRX_UNDO_UPD_EXIST_REC 12 /* update of a non-delete-marked
@@ -328,8 +328,8 @@ record */
storage fields: used by purge to
free the external storage */
-/** The search tuple corresponding to TRX_UNDO_INSERT_DEFAULT */
-extern const dtuple_t trx_undo_default_rec;
+/** The search tuple corresponding to TRX_UNDO_INSERT_METADATA */
+extern const dtuple_t trx_undo_metadata;
#include "trx0rec.ic"
diff --git a/storage/innobase/trx/trx0rec.cc b/storage/innobase/trx/trx0rec.cc
index 652154ae4c2..67b5617809f 100644
--- a/storage/innobase/trx/trx0rec.cc
+++ b/storage/innobase/trx/trx0rec.cc
@@ -40,8 +40,8 @@ Created 3/26/1996 Heikki Tuuri
#include "fsp0sysspace.h"
#include "row0mysql.h"
-/** The search tuple corresponding to TRX_UNDO_INSERT_DEFAULT */
-const dtuple_t trx_undo_default_rec = {
+/** The search tuple corresponding to TRX_UNDO_INSERT_METADATA */
+const dtuple_t trx_undo_metadata = {
REC_INFO_METADATA, 0, 0,
NULL, 0, NULL,
UT_LIST_NODE_T(dtuple_t)()
@@ -510,7 +510,7 @@ trx_undo_page_report_insert(
ut_ad(index->is_instant());
ut_ad(undo_block->frame[first_free + 2]
== TRX_UNDO_INSERT_REC);
- undo_block->frame[first_free + 2] = TRX_UNDO_INSERT_DEFAULT;
+ undo_block->frame[first_free + 2] = TRX_UNDO_INSERT_METADATA;
goto done;
}